/**
	* Cart JS
	*/

const miniCartContentMain = $('.miwix_cart-minicart'),
	cartContentMain = $('.miwix_cart'),
	cartContentHeader = $('.cart-miwix'),
	colorAnimationAddCart = '#d2151e',
	widthAnimationAddCart = '25px',
	heightAnimationAddCart = '25px';

function reloadCartInit() {
	$(function() {

		$(document).on('submit', 'form.order-cart-form', function(e) {
			var thisBtn = $(this);
			thisBtn.addClass('process-ajax');
			var formData = new FormData($(this)[0]);
			
			$.ajax({
				url: '/cart/order/',
				type: 'POST',
				headers: {
					"x-miwix-json": true,
				},
				data: formData,
				success: function (data) {
					if (typeof data != 'object') {
						data = JSON.parse(data);
					}
					if (data.res == true) {
						InfoDialog('Заказ выполнен!', data.message, true);
						setTimeout(function () {
							window.location.href = '/catalog/category/products/';
						}, 3000);
					} else {
						InfoDialog('Ошибка выполнения заказа!', data.message, false);
					}
				},
				complete: function() {	
					thisBtn.removeClass('process-ajax');
				},
				error: function() {
					alert('Ошибка при отправке!');
					thisBtn.removeClass('process-ajax');
				},
				cache: false,
				contentType: false,
				processData: false
			});
			
			e.preventDefault();
		});
		
		// delete item from cart 
		$(document).on('click', '.remove-cart-item', function(e) {
			e.preventDefault();

			removeCartItem($(this).closest('.cart_item').attr('data-id'));
		});
		
		// add product to cart
		$(document).on('click', '.miwix_add_to_cart', function(e) {
			e.preventDefault();

			let id = $(this).attr('data-product_id'),
				count = $(this).closest('.cart').find('.product-quantity').val(),
				thisBtn = $(this);

				thisBtn.addClass('process-ajax');
				const formData = new FormData();
				formData.append('id', id);
				formData.append('quantity', count ? count : 1);
				
				$.ajax({
					url: '/cart/add-product/',
					type: 'POST',
					headers: {
						"x-miwix-json": true,
					},
					data: formData,
					success: function (data) {
						if (typeof data != 'object') {
							var data = JSON.parse(data);
						}
						if (data.res == true) {
							localStorage.count_cart = data.cart.totalItems;
							reloadCart(data);
							animationAddCart(e);
						} else {
							alert(data.message ? data.message : 'Ошибка добавления в корзину');
						}
					},
					complete: function() {	
						thisBtn.removeClass('process-ajax');
					},
					error: function() {
						alert('Ошибка при отправке!');
						thisBtn.removeClass('process-ajax');
					},
					cache: false,
					contentType: false,
					processData: false
				});
		});
		
	});
}

reloadCartInit();

function animationAddCart(e) {
	$('body').append('<div class="animtocart"></div>');
	const cart = cartContentHeader.filter(':visible').offset();

	$('.animtocart').css({
		'position' : 'absolute',
		'background' : colorAnimationAddCart,
		'width' :  widthAnimationAddCart,
		'height' : heightAnimationAddCart,
		'border-radius' : '50%',
		'z-index' : '9999999999',
		'left' : e.pageX,
		'top' : e.pageY,
	});

	$('.animtocart').animate({ top: cart.top + 'px', left: cart.left + 'px', width: 0, height: 0 }, 2000, function(){
		$(this).remove();
	});
}

function ConfirmDialog(message, id) {
	$('<div></div>').appendTo('body')
	.html('<div><h5>'+message+'</h5></div>')
	.dialog({
		modal: true, 
		title: 'Удалить товар?', 
		zIndex: 999999999, 
		autoOpen: true,
		width: 'auto', 
		minWidth : 450,
		minHeight : 450,
		resizable: false,
		buttons: {
			Yes: {
				class: 'btn btn-danger new-btn btn-red',
				text: 'Удалить',
				click () {
					removeCartItemAjax(id);
					$(this).dialog("close");
				}
			},
			No: {
				class: 'btn btn-primary new-btn btn-blue',
				text: 'Отмена',
				click () {
					const self = this;
					setTimeout(function () {
						$(self).dialog("close");
					}, 500);
				}
				
			}
		},
		close: function (event, ui) {
			const self = this;
			setTimeout(function () {
				$(self).remove();
			}, 500);
		}
	});
	$('.ui-dialog-content').hide();
	$(".ui-dialog-titlebar .ui-dialog-titlebar-close").hide();
};
		
		
function InfoDialog(title, message, reload1) {
	$('<div></div>').appendTo('body')
	.html('<div><h5>'+message+'</h5></div>')
	.dialog({
			modal: true,
			title: title,
			zIndex: 999999999999999999999999,
			autoOpen: true,
			width: 'auto',
			resizable: false,
			minWidth : 450,
			buttons: {
				cart: {
					class: 'btn btn-primary',
					text: 'Каталог',
					click () {
						window.location.href = '/catalog/category/products/';
					}
				},
				close: {
					class: 'btn btn-light ',
					text: 'Закрыть',
					click () {
						$(this).dialog("close");
						if (reload1 == true) {
							$('html, body').scrollTop(0);
							location.reload();
						}
					}
				}
			},
			close: function (event, ui) {
				$(this).remove();
			}
		});
	$(".ui-draggable .ui-dialog-titlebar").hide();
	$(".ui-dialog-titlebar .ui-dialog-titlebar-close").hide();
};

function removeCartItem(productId) {
	ConfirmDialog('Удалить товар из корзины?', productId);
}
		
function removeCartItemAjax(id) {
	var cartContent = $('.miwix_cart'),
		cartItem = cartContent.find('.cart_item[data-id='+id+']'),
		cartForm = cartContent.find('form');
	
	cartItem.addClass('process-ajax');
	
	const formData = new FormData();
	formData.append('hash', id);
	
	$.ajax({
		url: '/cart/remove/',
		type: 'POST',
		headers: {
			"x-miwix-json": true,
		},
		data: formData,
		success: function (data) {
			if (typeof data != 'object') {
				data = JSON.parse(data);
			}
			localStorage.count_cart = data.cart.totalItems
			reloadCart(data);
			cartItem.remove();
		},
		complete: function() {	
			cartItem.removeClass('process-ajax');
		},
		error: function() {
			alert('Ошибка при отправке!');
			cartItem.removeClass('process-ajax');
		},
		cache: false,
		contentType: false,
		processData: false
	});
}

function updateCart(self) {
	let id = self.attr('data-id'),
		count = self.find('.quantity-selector .number').val();

	const formData = new FormData();
	formData.append('hash', id);
	formData.append('count', count ? count : 1);
	
	$.ajax({
		url: '/cart/update/',
		type: 'POST',
		headers: {
			"x-miwix-json": true,
		},
		data: formData,
		success: function (data) {
			if (typeof data != 'object') {
				data = JSON.parse(data);
			}
			localStorage.count_cart = data.cart.totalItems
			reloadCart(data);
		},
		error: function() {
			alert('Ошибка при отправке!');
		},
		cache: false,
		contentType: false,
		processData: false
	});
}

$(document).on('change', '.cart_item .quantity-selector input.number', function (e) {
	updateCart($(this).closest('.cart_item'));
})

function reloadCart(data) {
	if (data.cart.totalItems > 0) {
		cartContentHeader.find('.cart-miwix-count').html(data.cart.totalItems);

		cartContentMain.find('.cart-subtotal .amount').text(data.cart.totalAmountItemsFormatted);
		cartContentMain.find('.order-shipping .amount').text(data.cart.shippingAmountFormatted);
		cartContentMain.find('.order-total .amount').text(data.cart.totalAmountFormatted);
		$.each(data.cart.items, function(i,v) {
			cartContentMain.find('.cart_item[data-id='+v.hash+']').find('.product-subtotal .amount').text(v.totalPriceFormatted);
		});

		//обновим список в мини-корзине
		var cartItems = '';
		var html = '';

		$.each(data.cart.items, function(i,v) {
			cartItems += `<div class="cart_item single-cart-product" data-id="${v.hash}">
							<span class="cart-close-icon">
								<a class="remove-cart-item" href="#"><i class="ti-close"></i></a>
							</span>
							<div class="image">
								<a href="${v.details.url}">
									<img src="` + v.details.img[0][150] + `" class="img-fluid" alt="${v.details.img[0].alt}" title="${v.details.img[0].title}">
								</a>
							</div>
							<div class="content">
								<h5><a href="${v.details.url}">${v.details.name_abbr}</a></h5>
								<p><span class="cart-count">${v.count} x </span> <span class="discounted-price">${v.details.price_format}</span></p>

							</div>
						</div>`;
		});

		var html = `<div class="cart-product-container ps-scroll">
						${cartItems}
					</div>

					<p class="cart-subtotal">
						<span class="subtotal-title">Итого:</span>
						<span class="subtotal-amount">${data.cart.totalAmountStockFormatted}</span>
					</p>`;

		miniCartContentMain.html(html);
	} else {
		cartContentMain.html(`
			<div class="shopping-cart-area mb-100">
				<div class="container">
					<div class="row">
						<div class="col-md-12">
							<h5 class="text-center">Ваша корзина пуста</h5>
						</div>
					</div>
				</div>
			</div>
		`);
		cartContentHeader.find('.cart-miwix-count').html(data.cart.totalItems);

		var html = `<div class="cart-product-container ps-scroll">
						<h5 class="text-black m-a0">Корзина пуста!</h5>
					</div>`;
		miniCartContentMain.html(html);
	}
}
