
/**
	* Catalog module frontend JS v 1.0
*/
(function ($) {
	"use strict";

	let $filtersFrom = $('#filters-form'),
		$filterRange = $filtersFrom.find('.filter-range'),
		$filterList = $filtersFrom.find('.filter-list'),
		$pagination = $('.products-view__pagination'),
		$filtersRangeValue = {},
		$filtersListValue = {},
		$page = '?page=' + 1,
		$numberPage = 1,
		$lastPage = 1,
		$queryTimeOut,
		$queryCatalog,
		$isLoad = false,
		$isNextPage = false,
		json_filters = {},
		widgetFilters = $('.widget-filters'),
		widgetFiltersItem = widgetFilters.find('.widget-filters__item');

	init();

	function init () {
		pageInit();
		initFilterList();
		disabledPage();
	}

	function pageInit () {
		let params = window.location.search.replace('?','').split('&').reduce(function (p, e) {
        	let a = e.split('=');
        	if (a[0] === 'page') {
        		$numberPage = parseInt(a[1]);
        		$page = '?page=' + a[1];
        	}		            
	    }, {});
	}

	$filtersFrom.submit(function (e) {
		e.preventDefault();
	});

	$filterRange.find('input.range').change(function (e) {
		e.preventDefault();
		$page = '?page=' + 1;
		let keys = $(this).data('name').split('-');
		if (!$filtersRangeValue[keys[0]]) {
			$filtersRangeValue[keys[0]] = {};
		}
		if (!$filtersRangeValue[keys[0]][keys[1]]) {
			$filtersRangeValue[keys[0]][keys[1]] = {};
		}
		$filtersRangeValue[keys[0]][keys[1]]['value'] = $(this).val();

		
		if ($queryTimeOut) {
			clearTimeout($queryTimeOut);
		}

		$queryTimeOut = setTimeout(function () {
			queryCatalog();
		}, 500);
	});

	$filterList.find('input.list').change(function (e) {
		e.preventDefault();

		$page = '?page=' + 1;
		
		arrayFiltersList(this);

		if ($queryTimeOut) {
			clearTimeout($queryTimeOut);
		}

		$queryTimeOut = setTimeout(function () {
			queryCatalog();
		}, 500);
	});

	$(document).on('click', '.pagination a[href^="?page"]', function (e) {
		e.preventDefault();
		let href = $(this).attr('href');
		if (!$isLoad) {
			$isLoad = true;
		}

		$numberPage = (parseInt(href.match(/page=(\d+)&?/im)[1]));
		$page = '?page=' + $numberPage;

		if ($queryTimeOut) {
			clearTimeout($queryTimeOut);
		}

		$queryTimeOut = setTimeout(function () {
			queryCatalog();
		}, 500);
	});

	function generationQueryRangeFiltersUrl () {
		Object.keys($filtersRangeValue).forEach(function (k) {
			$queryCatalog += `filters[${k}][min]=${$filtersRangeValue[k].min.value}&`
			$queryCatalog += `filters[${k}][max]=${$filtersRangeValue[k].max.value}&`
		});
	}

	function generationQueryListFiltersUrl () {
		Object.keys($filtersListValue).forEach(function (key) {
			Object.keys($filtersListValue[key]).forEach(function (k) {
				$queryCatalog += `filters[${key}][${k}]=${$filtersListValue[key][k].value}&`
			});
		});
	}

	$('.widget-filters__list').find('input[type="reset"]').on('click', function (e) {
		e.preventDefault();
		$page = '?page=' + 1;
		$filtersRangeValue = {};
		$filtersListValue = {};

		$filterList.find('input.list:checked').prop('checked', false);

		$('.filter-price').each(function (i, element) {
	        const slider = element.querySelector('.filter-price__slider');
			slider.noUiSlider.set([$('.price-default-min').val(), $('.price-default-max').val()]);
	    });

		queryCatalog();
	});

	$('.next-page').click(function (e) {
		e.preventDefault();

		if (!$isLoad) {
			$isLoad = true;
		}

		$numberPage++;
		if ($lastPage >= $numberPage) {
			$page = '?page=' + $numberPage;

			if ($queryTimeOut) {
				clearTimeout($queryTimeOut);
			}

			$queryTimeOut = setTimeout(function () {
				$isNextPage = true;
				let scrollTop = $(document).scrollTop();
				queryCatalog();
				$(document).scrollTop(scrollTop);
			}, 500);
		}
	});

	function disabledPage() {
		lastPage();
		if ($lastPage <= $numberPage) {
			$pagination.find('.next-page').prop('disabled', true);
		} else {
			$pagination.find('.next-page').prop('disabled', false);
		}
	}

	function lastPage () {
		let last = $pagination.find('.page-item:last')[0];
		if (last) {
			$lastPage = parseInt(last.innerText);
		} else {
			$lastPage = 0;
		}
	}

	function queryCatalog () {
		if ($isLoad) {
			$queryCatalog = '';
			generationQueryRangeFiltersUrl();
			generationQueryListFiltersUrl();

			window.location.search.replace('?','').split('&').forEach(function (v) {
				let a = v.split('=');
				a[0] = decodeURIComponent(a[0]);
				a[1] = decodeURIComponent(a[1]);
				if (a[0] === 'psort') {
					$page += '&psort=' + a[1];
				} else if (a[0] === 'limit') {
					$page += '&limit=' + a[1];
				} else if (a[0] === 'sort_up') {
					$page += '&sort_up=' + a[1];
				} else if (a[0] === 'q') {
					$page += '&q=' + a[1];
				} else if (a[0] === 'category') {
					$page += '&category=' + a[1]
				}
			});

			let url = encodeURI(window.location.pathname + $page + ($queryCatalog ? '&' + ($queryCatalog.slice(0, -1)) : ''));

			history.pushState({'page': $page}, 'Каталог страница ' + $page, url);

			let container = $('#products-miwix'),
				response = '#products-miwix',
				paginationClass = '.pagination',
				productsCountClass = '.products-view__options .view-options__legend',
				filters_json_block = '#filters-json-block';

			container.addClass('process-ajax');

			$.ajax({
				type: "GET",
				url: url,
				success: function(data) {
					let content = $(response, data).html();
					let paginationData = $(paginationClass, data).html();
					let productsCountData = $(productsCountClass, data).html();
					let filtersBlock = $(filters_json_block, data).html();

					if ($isNextPage) {
						$isNextPage = false;
					    $(response).append(content);
					} else {
						container.html(content);
					}

					if (paginationData) {
						$(paginationClass).html(paginationData);
					} else {
						$(paginationClass).html('');
					}

					$(productsCountClass).html(productsCountData);
					if ($(filters_json_block).length && filtersBlock) {
						json_filters = JSON.parse(filtersBlock);
						widgetFiltersItem.find('.input-check__body input').prop('disabled', true);
						Object.keys(json_filters).forEach(function (k) {
							Object.keys(json_filters[k].children).forEach(function (kk) {
								let el = widgetFiltersItem.find('.input-check__body input[name^="filters['+k+']['+kk+']"]').prop('disabled', false);
							});
						});
					} else {
						widgetFiltersItem.find('.input-check__body input[name^="filters"]').prop('disabled', false);
					}

					disabledPage();
				},
				complete: function(){
					container.removeClass('process-ajax');
				},
				error: function(data){
					/*console.log(url)
					alert("Ошибка отправки запроса. Сервер временно занят, попробуйте через минуту.");*/
				},
				cache: false,
				contentType: false,
				processData: false
			});
		} else {
			$isLoad = true;
		}
	}

	function initFilterList () {
		$filterList.find('input.list').each(function (k, v) {
			arrayFiltersList(v);
		});
	}

	function arrayFiltersList (v) {
		let keys = $(v).data('name').split(':');

		if ($(v)[0].checked) {
			if (!$filtersListValue[keys[0]]) {
				$filtersListValue[keys[0]] = {};
			}

			if (!$filtersListValue[keys[0]][keys[1]]) {
				$filtersListValue[keys[0]][keys[1]] = {};
			}
			$filtersListValue[keys[0]][keys[1]]['value'] = $(v).val();
		} else if (!$(v)[0].checked && $filtersListValue[keys[0]] && $filtersListValue[keys[0]][keys[1]]) {
			delete $filtersListValue[keys[0]][keys[1]];
		}
	}

	$('#simple-limit').on('change', 'select', function (e) {
		let limit = $(this).val(),
			pathName = window.location.pathname,
			getParams = window.location.search,
			params,
			url;

		if (getParams.match(/limit/)) {
			params = getParams.replace(/limit=(\d*)/, `limit=${limit}`)
		} else {
			params = getParams ? `${getParams}&limit=${limit}` : `?limit=${limit}`;
		}
		
		url = `${pathName}${params}`;
		window.location.href = url;
	});

	$('#simple-sort').on('change', 'select', function (e) {
		let sort = $(this).val(),
			pathName = window.location.pathname,
			getParams = window.location.search,
			params,
			url;

		if (getParams.match(/psort/)) {
			params = getParams.replace(/psort=(\w*)\??/, `psort=${sort}`)
		} else {
			params = getParams ? `${getParams}&psort=${sort}` : `?psort=${sort}`;
		}
		
		url = `${pathName}${params}`;
		window.location.href = url;
	});

	$('.cart-table__more-details').on('click', function (e) {
		e.preventDefault();
		let el = $(this).parents('.cart-table__column').find('.cart-table__options');
		if ($(this).attr('data-views') === 'true') {
			let height = el[0].scrollHeight;
			el.animate({height: '18px'}, 800);
			$(this).text('Показать');
			$(this).attr('data-views', false);
		} else {
			let height = el[0].scrollHeight;
			el.animate({height: height + 'px'}, 800);
			$(this).text('Скрыть');
			$(this).attr('data-views', true);
		}
	});
	const productsViews = $('#products-user-views');
	if (localStorage.products_id && productsViews.length) {
		const formData = new FormData();
		formData.append('ids', localStorage.products_id);
		$.ajax({
			type: "POST",
			url: '/catalog/views-products/',
			headers: {
				"x-miwix-json": true,
			},
			data: formData,
			success: function(data) {
				let html = '';
				if (data.res === true && data.products.length) {
					data.products.forEach(function (v) {
						html += `
						<div class="block-products__list-item">
							<div class="product-card product-card--hidden-actions ">`;
								if (v.price_old > 0) {
									html += `
								<div class="product-card__badges-list">
									<div class="product-card__badge product-card__badge--sale">Sale</div>
								</div>
									`
								}
						html +=
								`<div class="product-card__image product-image">
									<a href="${v.url}" class="product-image__body">
										<img class="product-image__img" src="${v['img'][0]['900']}" alt="${v['img'][0]['alt']}" title="${v['img'][0]['title']}">
									</a>
								</div>
								<div class="product-card__info">
									<div class="product-card__name">
										<a href="${v.url}">${v.name}</a>
										<ul class="product__meta mb-10">
											<li>Артикул: ${v.articul}</li>
										</ul>
									</div>
								</div>
								<div class="product-card__actions">
									<div class="product-card__price">`;
								if (v.price <= 0) {
									html += `
										<div class="product-card__prices">Нет в наличии</div>`;
								}

									html += '<p><strong>Цена</strong></p>';
								if (v.price_old > 0) {
									html += `
										<span class="product-card__new-price">${v.price_format}</span>
										<span class="product-card__old-price">${v.price_old_format}</span>`;
								} else {
									html += `
										<div class="product-card__prices">${v.price_format}</div>`;
								}
												
						html += `
									</div>`;
						if (v.price > 0) {
							html += `
									<div class="product-card__buttons">
										<div class="product__actions-item">
											<div class="input-number product__quantity">
												<input class="input-number__input form-control form-control-lg number" type="number" min="1" value="1">
												<div class="input-number__add"></div>
												<div class="input-number__sub"></div>
											</div>
										</div>
										<button class="btn btn-primary product-card__addtocart miwix_add_to_cart" type="button" data-product_id="${v.id}">
											<svg id="icon-corb" viewBox="0 0 32 32"><path d="M30.5 11.65c-0.1-0.15-0.3-0.25-0.5-0.25h-22.5l-1.9-7.55c-0.050-0.3-0.3-0.45-0.6-0.45h-5c-0.35 0-0.65 0.3-0.65 0.65s0.3 0.65 0.65 0.65h4.5l1.9 7.5c0 0 0 0 0 0l3 12c0.050 0.3 0.3 0.45 0.6 0.45h16c0.25 0 0.5-0.15 0.6-0.45l4-12c0.050-0.2 0-0.4-0.1-0.55zM25.55 23.35h-15.050l-2.7-10.75h21.35l-3.6 10.75z"></path><path d="M10.5 25.35c-1.45 0-2.65 1.2-2.65 2.65s1.2 2.65 2.65 2.65 2.65-1.2 2.65-2.65-1.2-2.65-2.65-2.65zM10.5 29.35c-0.75 0-1.4-0.6-1.4-1.4s0.6-1.4 1.4-1.4 1.4 0.6 1.4 1.4-0.65 1.4-1.4 1.4z"></path><path d="M23.5 25.35c-1.45 0-2.65 1.2-2.65 2.65s1.2 2.65 2.65 2.65 2.65-1.2 2.65-2.65-1.2-2.65-2.65-2.65zM23.5 29.35c-0.75 0-1.4-0.6-1.4-1.4s0.6-1.4 1.4-1.4 1.4 0.6 1.4 1.4-0.65 1.4-1.4 1.4z"></path></svg>
										</button>
									</div>`;
						}
						html += `
								</div>
							</div>
						</div>`;
					});
					productsViews.show();
					productsViews.find('.block-products__list').html(html);
				}
			},
			cache: false,
			contentType: false,
			processData: false
		});
	}
})(jQuery);